==> onecx-permissions-client-0.12.0-sources.jar: gen/org/tkit/onecx/permission/model/PermissionRequest.java <==
package gen.org.tkit.onecx.permission.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class PermissionRequest  {

    private String token;

    /**
    * Get token
    * @return token
    **/
    @JsonProperty("token")
    public String getToken() {
        return token;
    }

    /**
     * Set token
     **/
    public void setToken(String token) {
        this.token = token;
    }

    public PermissionRequest token(String token) {
        this.token = token;
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PermissionRequest {\n");

        sb.append("    token: ").append(toIndentedString(token)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public static class PermissionRequestQueryParam  {

        @jakarta.ws.rs.QueryParam("token")
        private String token;

        /**
        * Get token
        * @return token
        **/
        @JsonProperty("token")
        public String getToken() {
            return token;
        }

        /**
         * Set token
         **/
        public void setToken(String token) {
            this.token = token;
        }

        public PermissionRequestQueryParam token(String token) {
            this.token = token;
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class PermissionRequestQueryParam {\n");

            sb.append("    token: ").append(toIndentedString(token)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }
}

==> onecx-permissions-client-0.20.0-sources.jar: gen/org/tkit/onecx/permission/model/PermissionRequest.java <==
package gen.org.tkit.onecx.permission.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
public class PermissionRequest  {

    private String token;

    /**
    * Get token
    * @return token
    **/
    @JsonProperty("token")
    public String getToken() {
        return token;
    }

    /**
     * Set token
     **/
    public void setToken(String token) {
        this.token = token;
    }

    public PermissionRequest token(String token) {
        this.token = token;
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PermissionRequest {\n");

        sb.append("    token: ").append(toIndentedString(token)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class PermissionRequestQueryParam  {

        @jakarta.ws.rs.QueryParam("token")
        private String token;

        /**
        * Get token
        * @return token
        **/
        @JsonProperty("token")
        public String getToken() {
            return token;
        }

        /**
         * Set token
         **/
        public void setToken(String token) {
            this.token = token;
        }

        public PermissionRequestQueryParam token(String token) {
            this.token = token;
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class PermissionRequestQueryParam {\n");

            sb.append("    token: ").append(toIndentedString(token)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }
}
